/***************************** FILE HEADER *********************************/
/*!
*  \file      clickQlabel.cpp
*
*  \brief     This file implements ComboBoxes in the property table.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "comboboxdelegate.h"

/******************************************************************************
 * Globals
 ******************************************************************************/
extern QVariant oldValue;
extern bool boolTableClickflag;

/****************************************************************************************
Function Name			:	ComboBoxDelegate
Function/DLD ID 		:   SWR_CBD_01
Purpose of Function		:   Constructor of ComboBoxDelegate
Author/Date     		: 	<Manu Singh  22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   Parent
Return                  :   Void
Remarks                 :
*****************************************************************************************/
ComboBoxDelegate::ComboBoxDelegate(QObject *parent)
    : QStyledItemDelegate(parent)
{
}
/****************************************************************************************
Function Name			:	createEditor
Function/DLD ID 		:   SWR_CBD_02
Purpose of Function		:   Customize the QLable for clicking
Author/Date     		: 	<Manu Singh  22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   Parent, QStyleOptionViewItem, QModelIndex
Return                  :   QWidget
Remarks                 :
*****************************************************************************************/
QWidget *ComboBoxDelegate::createEditor(QWidget *parent,
    const QStyleOptionViewItem &/* option */,
    const QModelIndex & QModelIndexIndex ) const
{
    QComboBox *editor = new QComboBox(parent);
    //Add item combobox based on location in table
    switch(QModelIndexIndex.column())
    {
        case 0:             //ui->comboBox_adminState
        case 1:             //ui->comboBox_alarmLink
        case 2:             //ui->comboBox_autoNeg
        case 5:             //ui->comboBox_autoCrossing
        case 7:             //ui->comboBox_flowControl
        case 8:             //ui->comboBox_broadcastStormProtection
        case 10:            //ui->comboBox_multicastStormProtection
        case 12:            //ui->comboBox_jumboFrames
        case 15:            //ui->comboBox_eee

            editor->addItem("Off");
            editor->addItem("On");
            break;
        case 3:             //ui->comboBox_speed
            editor->addItem("10Mbps");
            editor->addItem("100Mbps");
            //editor->addItem("-");

            break;
        case 4:             //ui->comboBox_duplexMode
            editor->addItem("HDX");
            editor->addItem("FDX");
            break;
        case 6:             //ui->comboBox_mdiState
            editor->addItem("MDI");
            editor->addItem("MDIX");
            break;
        case 16:            //ui->comboBox_poeAdminState
            editor->addItem("Off");
            editor->addItem("On");

            break;
        case 17:            //ui->comboBox_poePriority
            editor->addItem("Low");
            editor->addItem("High");
            editor->addItem("Critical");

            break;
        case 14:            //ui->comboBox_portpriority
            editor->addItem("0");
            editor->addItem("1");
            editor->addItem("2");
            editor->addItem("3");
            editor->addItem("4");
            editor->addItem("5");
            editor->addItem("6");
            editor->addItem("7");
        default:
            break;
    }
    //Connect signal with slot when index is chaned
    connect(editor, SIGNAL(currentIndexChanged(QString)), this, SLOT(onCurrentIndexChanged(QString)),Qt::UniqueConnection);

    // Change value only when table is clicked. To prevent TAB key events
    if(boolTableClickflag)
    {
        boolTableClickflag = false;
        editor->setCurrentIndex(editor->findText(oldValue.toString()));
    }
    return editor;
}
/****************************************************************************************
Function Name			:	setEditorData
Function/DLD ID 		:   SWR_CBD_03
Purpose of Function		:   Set editor data
Author/Date     		: 	<Manu Singh  22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void ComboBoxDelegate::setEditorData(QWidget *editor,
                                    const QModelIndex &index) const
{
    QVariant::Type type = index.model()->data(index).type();
    // Set data to QWidget
    switch(type)
    {
        case QVariant::StringList:
        {
            QComboBox* comboBox = static_cast<QComboBox*>(editor);
            if (comboBox == 0)
                return;
            QVariant value = index.model()->data(index,Qt::EditRole); 
            comboBox->setCurrentIndex(value.toInt());
            break;
        }
        default:
            break;
    }

}
/****************************************************************************************
Function Name			:	setModelData
Function/DLD ID 		:   SWR_CBD_04
Purpose of Function		:   Set model data to combo box
Author/Date     		: 	<Manu Singh 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QAbstractItemModel, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void ComboBoxDelegate::setModelData(QWidget *QWidgetEditor, QAbstractItemModel *QAbstractItemModelModel,
                                   const QModelIndex &QModelIndexIndex) const
{
    // Set data on index to combobox
    QComboBox *comboBox = static_cast<QComboBox*>(QWidgetEditor);
    if(comboBox==0)
        return;
    if(boolTableClickflag)
    {
        boolTableClickflag = false;

        QAbstractItemModelModel->setData(QModelIndexIndex, comboBox->currentText(), Qt::EditRole);
    }
}
/****************************************************************************************
Function Name			:	updateEditorGeometry
Function/DLD ID 		:   SWR_CBD_05
Purpose of Function		:   Update geometry of combobox
Author/Date     		: 	<Manu Singh 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QStyleOptionViewItem, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void ComboBoxDelegate::updateEditorGeometry(QWidget *QWidgetEditor,
    const QStyleOptionViewItem &QStyleOptionViewItemOption, const QModelIndex &/* index */) const
{
    QWidgetEditor->setGeometry(QStyleOptionViewItemOption.rect);
}
/****************************************************************************************
Function Name			:	onCurrentIndexChanged
Function/DLD ID 		:   SWR_CBD_06
Purpose of Function		:   Emit singal about change in current index value of combobox from model
Author/Date     		: 	<Manu Singh 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void ComboBoxDelegate::onCurrentIndexChanged(QString QStringValueText)
{
    emit currentValueofCombo(QStringValueText);
}
