/***************************** FILE HEADER *********************************/
/*!
*  \file      dialogconfigid.cpp
*
*  \brief     This file implements the dialog that enables the user to chose his/her product.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "dialogconfigid.h"
#include "ui_dialogconfigid.h"
#include <QDebug>
#include <QSignalMapper>

/******************************************************************************
 * Globals
 ******************************************************************************/
extern unsigned char configIdfromcsv;

unsigned char prodindex;

/****************************************************************************************
Function Name			:	DialogConfigID
Function/DLD ID 		:
Purpose of Function		:   Constructor of dialog box for for csv files
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogConfigID::DialogConfigID(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogConfigID)
{
    ui->setupUi(this);
    // setting title for Dialog window
    this->setWindowTitle("csv File");

    //Disabling extra buttons
    setWindowFlags(Qt::WindowTitleHint | Qt::Dialog | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);

    dynamicAdditionRadiobuttons();
    settingRadiobuttons(configIdfromcsv);
}

/****************************************************************************************
Function Name			:	~DialogConfigID
Function/DLD ID 		:
Purpose of Function		:   Deconstructor of dialog box for csv files
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogConfigID::~DialogConfigID()
{
    delete ui;
}
/****************************************************************************************
Function Name			:	settingRadiobuttons
Function/DLD ID 		:
Purpose of Function		:   set the radiobuttons on the dialog box
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void DialogConfigID::settingRadiobuttons(unsigned char idfromcsv)
{
    int *array_temp;
    array_temp = new int[3];
    int j=0;

    for(int i=0;i<MAX_PRODUCT_NUMBERS;i++)
    {
        if((stProductData[i].m_ucProductId)==idfromcsv)
        {
            array_temp[j] = i ;
            j++;
        }
    }
     for(int k=0; k<j;k++)
     {
         rb_csv[k]->setText(stProductData[array_temp[k]].m_qsProductName);
         rb_csv[k]->show();
     }
     rb_csv[0]->setChecked(true);

}

/****************************************************************************************
Function Name			:	dynamicAdditionRadiobuttons
Function/DLD ID 		:
Purpose of Function		:   add the radio buttons on GUI
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/

void DialogConfigID::dynamicAdditionRadiobuttons()
{
    Vlayout = new QVBoxLayout();
    gb_Listofbuttons = new QGroupBox();
    csvlabel = new QLabel("Which csv file would you like to open?");

    QSignalMapper* radioButtonMapper = new QSignalMapper (this) ;
    Vlayout->addStretch(1);
    Vlayout->addWidget(csvlabel,0,Qt::AlignVCenter);
    for(int i=0; i< 3; i++)
    {
        rb_csv[i] = new QRadioButton();
        Vlayout->addStretch(2);
        Vlayout->addWidget(rb_csv[i],0,Qt::AlignVCenter);
        rb_csv[i]->hide();
        connect(rb_csv[i], SIGNAL(clicked(bool)), radioButtonMapper, SLOT(map())) ;
        radioButtonMapper->setMapping(rb_csv[i],i);
    }
    Vlayout->addStretch(3);
    connect(radioButtonMapper, SIGNAL(mapped(int)), this, SLOT(radioButtonSelect(int)));

    Vlayout->addWidget(ui->buttonBox_configId);
    this->setLayout(Vlayout);

}

/****************************************************************************************
Function Name			:	radioButtonSelect
Function/DLD ID 		:
Purpose of Function		:   index of the radio button is changed
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/

void DialogConfigID::radioButtonSelect(int select)
{
    prodindex=(unsigned char)select;
}

/****************************************************************************************
Function Name			:	on_buttonBox_configId_accepted
Function/DLD ID 		:
Purpose of Function		:   accepts the selected radiobutton value
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/

void DialogConfigID::on_buttonBox_configId_accepted()
{

}

/****************************************************************************************
Function Name			:	on_buttonBox_configId_rejected
Function/DLD ID 		:
Purpose of Function		:   closes the dialog box
Author/Date     		: 	<Manu Singh 01\12\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/

void DialogConfigID::on_buttonBox_configId_rejected()
{

}
