/***************************** FILE HEADER *********************************/
/*!
*  \file      dialogerrorlog.cpp
*
*  \brief     This file implements the dialog that handles errors from opening a file.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "dialogerrorlog.h"
#include "ui_dialogerrorlog.h"
#include <QStringList>
#include <QStandardItemModel>

/******************************************************************************
 * Globals
 ******************************************************************************/
// Global variable used to share errors
extern QStringList errorList;

/****************************************************************************************
Function Name			:	DialogErrorLog
Function/DLD ID 		:   SWR_DERR_01
Purpose of Function		:   Constructor for error log dialog box
Author/Date     		: 	<Manu Singh 17\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogErrorLog::DialogErrorLog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogErrorLog)
{
    ui->setupUi(this);

    // Setting title
    this->setWindowTitle("Error Log");
    setWindowFlags(Qt::WindowTitleHint | Qt::Dialog | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);
    ui->tableWidget_errorLog->setColumnCount(4);
    //Clear previous error data from table
    ui->tableWidget_errorLog->clear();

    //Setting table format
    ui->tableWidget_errorLog->setColumnWidth(0, 50);
    ui->tableWidget_errorLog->setColumnWidth(1, 100);
    ui->tableWidget_errorLog->setColumnWidth(2, 50);
    ui->tableWidget_errorLog->setColumnWidth(3, 50);
    ui->tableWidget_errorLog->setColumnWidth(4, 50);

    // Adding header to table
    QStringList list;
    list=(QStringList() << "Line No."
                        << "Parameter Name"
                        << "Index"
                        << "Value"
                        << "Error Reason");
    ui->tableWidget_errorLog->setHorizontalHeaderLabels(list);

    // Populating error data on table
    for(int i=0;i< errorList.length();i++)
    {
        QStringList errorSplit = errorList[i].split(",");
        ui->tableWidget_errorLog->insertRow(i);
        ui->tableWidget_errorLog->setItem(i,0,new QTableWidgetItem(errorSplit[0]));
        ui->tableWidget_errorLog->setItem(i,1,new QTableWidgetItem(errorSplit[1]));
        ui->tableWidget_errorLog->setItem(i,2,new QTableWidgetItem(errorSplit[2]));
        ui->tableWidget_errorLog->setItem(i,3,new QTableWidgetItem(errorSplit[3]));

        switch((errorSplit[4]).toInt())
        {
            case 1:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Not valid parameter"));
                break;
            case 2:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Not valid Line"));
                break;
            case 3:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Not valid type"));
                break;
            case 4:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Not valid index"));
                break;
            case 5:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Not valid value"));
                break;
            default:
                ui->tableWidget_errorLog->setItem(i,4,new QTableWidgetItem("Unknown error"));
                break;
        }

    }

}
/****************************************************************************************
Function Name			:	~DialogErrorLog
Function/DLD ID 		:   SWR_DERR_02
Purpose of Function		:   Deconstructor for error log dialog box
Author/Date     		: 	<Manu Singh 17\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogErrorLog::~DialogErrorLog()
{
    delete ui;
}
/****************************************************************************************
Function Name			:	on_pushButton_clicked
Function/DLD ID 		:   SWR_DERR_03
Purpose of Function		:   press ok button to close dialog box
Author/Date     		: 	<Manu Singh 17\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void DialogErrorLog::on_pushButton_clicked()
{
    close();
}
