/***************************** FILE HEADER *********************************/
/*!
*  \file      globaldata.h
*
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

#ifndef GLOBALDATA_H
#define GLOBALDATA_H

#include <QRect>
#include <QString>


//#define MAX_PRODUCT_NUMBERS     25
#define MAX_PRODUCT_NUMBERS     18
#define MAX_NO_OF_PORTS     32
#define MAX_NO_OF_PARAMETERS    19


#define LOGO_FILE_NAME              "logo.png"
#define ICON_FILE_NAME              "icon.png"

#define APPLICATION_SOFTWARE_NAME   "Switch Programming Tool"
#define REPORT_LOGO_FILE_NAME       "report_logo.png"

                                  //QColor(R, G, B,255)
#define SOFTWARE_BACKGROUND         QColor(218, 224, 234,255)

//#define WEBSITE_LINK                "http://www.beldensolutions.com"
#define WEBSITE_LINK                "http://hirschmann.com/en/Hirschmann_Produkte/Industrial_Ethernet/Unmanaged-Switches/index.phtml"

#define SKETCH_BORDER_COLOR         "White"
#define PRODUCT_BORDER_COLOR        "Purple"

#define PRODUCT_LINE_SL                     1U
#define PRODUCT_LINE_PL                     2U
#define PRODUCT_LINE_POE                    4U
#define PRODUCT_LINE_OCT                    8U

#define PRODUCT_TYPE_FE                     1U
#define PRODUCT_TYPE_GE                     2U

#define PRODUCT_ABLE_JUMBO                  1
#define PRODUCT_NO_JUMBO                    0

#define SERVICE_MODE    1

#define LINUX   0


#define MAX_PORT_LABEL_SIZE          100
#define MIN_PORT_LABEL_SIZE          20




#define DEBUG   0


enum SELECTED_PORT_TYPE {
    NO_PORT_SELECTED,
    TP_FE_PORT_SELECTED,
    TP_FE_POE_PORT_SELECTED,
    TP_GE_PORT_SELECTED,
    TP_GE_POE_PORT_SELECTED,
    FIBER_FE_PORT_SELECTED,
    FIBER_GE_PORT_SELECTED
};

#pragma pack(1)
typedef struct
{
    unsigned char aucreleaseNo[8];
    unsigned char aucalarmPsu[2]; //  0: power supply1, 1: Power supply 2
    unsigned int  agingTime;     // ranges from 0 to 1048575s
    unsigned char aucpriority[4]; // priority for 4 traffic class 0: SP, 1: WRR
    unsigned char aucdotp1PcpToTc[8]; // mapping between port priority & traffic classes
    unsigned char aucdscpD1D2[64]; // mapping between dscp priority & traffic class
    unsigned char aucflowControlStatus[MAX_NO_OF_PORTS]; // per port flow control
    unsigned char aucadminState [MAX_NO_OF_PORTS];// per port enable/disable
    unsigned char aucjumboFrameStatus [MAX_NO_OF_PORTS]; // Per port jumbo frame
    unsigned char aucbcStormStatus [MAX_NO_OF_PORTS]; // per port broadcast storm protection status
    unsigned char aucbcStormThresold[MAX_NO_OF_PORTS]; //per port broadcast storm protection threshold
    unsigned char aucmcStormStatus[MAX_NO_OF_PORTS]; // per port multicast storm protection status
    unsigned char aucmcStormThresold[MAX_NO_OF_PORTS]; // per port multicast storm protection threshold
    unsigned char aucTrustMode[MAX_NO_OF_PORTS]; // per port Trustmode

    unsigned char auclinkAlarmStatus[MAX_NO_OF_PORTS]; // per port link alarm status
    unsigned char aucautonegStatus[MAX_NO_OF_PORTS]; // per port auto-neg status
    unsigned char aucspeed[MAX_NO_OF_PORTS]; // per port speed  1:10,2:100
    unsigned char aucduplexMode[MAX_NO_OF_PORTS]; // per port duplex mode , 1: full, 0: half
    unsigned char aucautoCrossingstatus[MAX_NO_OF_PORTS]; // per port auto-cross status
    unsigned char aucMdistatus[MAX_NO_OF_PORTS]; // per port auto-cross status
    unsigned char aucEEEStatus[MAX_NO_OF_PORTS]; // per port EEE status
    unsigned char aucpoeStatus[MAX_NO_OF_PORTS]; // per port Poe status
    unsigned char aucpoePriority[MAX_NO_OF_PORTS]; // per port poe priority , 1: low, 2: medium, 3: high
    unsigned char aucpoeAllowedClasses[MAX_NO_OF_PORTS][8];//MAX_NO_OF_PORTS][8]; // per port allowed classes

    unsigned short aucportVLANID[MAX_NO_OF_PORTS]; // VLAN just for testing purpose

    /*** Newly added ***/
    unsigned char aucproductid;
    unsigned char auccontactname[100];
    unsigned char auclocation[100];
    unsigned char auccomponentid[9];
    unsigned char aucportBasedQoS[MAX_NO_OF_PORTS]; //per port PortPriority
    /* new: 02.0.01 B10: */
    uint8_t globalTrustMode; // global QoS trust mode
    uint16_t aucpoeAllowedConsumptionOverride[MAX_NO_OF_PORTS]; //per port allowed consumption override value
} configData;

typedef struct stdefaultdata
{
    unsigned char aucreleaseNo[8];
    unsigned char aucalarmPsu[2];
    unsigned int agingTime;
    unsigned char aucpriority[4];
    unsigned char aucdotp1PcpToTc[8];
    unsigned char aucdscpD1D2[64];
    unsigned char aucflowControlStatus; // per port flow control
    unsigned char aucadminState;// per port enable/disable
    unsigned char aucjumboFrameStatus; // Per port jumbo frame
    unsigned char aucbcStormStatus; // per port broadcast storm protection status
    unsigned char aucbcStormThresold; //per port broadcast storm protection threshold
    unsigned char aucmcStormStatus; // per port multicast storm protection status
    unsigned char aucmcStormThresold; // per port multicast storm protection threshold
    unsigned char aucTrustMode; // per port Trustmode
    unsigned int  aucportBasedQoS;//per port priority
    unsigned char auclinkAlarmStatus; // per port link alarm status
    unsigned char aucautonegStatus; // per port auto-neg status
    unsigned char aucspeed; // per port speed  1:10,2:100
    unsigned char aucduplexMode; // per port duplex mode , 1: full, 0: half
    unsigned char aucautoCrossingstatus; // per port auto-cross status
    unsigned char aucMdistatus; // per port auto-cross status
    unsigned char aucEEEStatus; // per port EEE status
    unsigned char aucpoeStatus; // per port Poe status
    unsigned char aucpoePriority; // per port poe priority , 1: low, 2: medium, 3: high
    unsigned char aucpoeAllowedClasses[8]; // per port allowed classes

    unsigned short aucportVLANID; // VLAN just for testing purpose
    /* new: 02.0.01 B10: */
    uint8_t globalTrustMode; // global QoS trust mode
    uint16_t aucpoeAllowedConsumptionOverride; //per port allowed consumption override value
}defaultdata;

typedef struct
{
    unsigned char m_ucproductId;
    unsigned char m_ucproductLine; // SL, PL, POE
    unsigned char m_ucproductType; // FE, GE
    unsigned char m_ucnoOfPort; // No of Total ports
    unsigned char m_ucnoOfFiberPort; // No of fiber ports
    unsigned char m_uctypeOfFiberPort; // SC/ST, SFP
    unsigned char m_ucnoOfMediaConPhy; // Total number of media convertor
    unsigned char m_ucnoOfPSEController; // total number of PSE controller; 1  for 1- 4 ports, 2  8 port for POE
    unsigned char m_ucPoeAvailablePower; // total available power budget; 30 for 1 port, 60 for 4 ports, 120 for 8 ports
}productInfo;

typedef struct stPOEInfo
{
    unsigned char m_ucPOEAdminSate[8];
    unsigned char m_ucPOEPriority[8];
    unsigned char m_ucAllowedClassis[8];
    float m_fTotalAvailablePower;
    float m_fClassInfo[8];
    uint16_t m_ucAllowedConsumptionOverride[8];
}POEInfo;



typedef struct
{
    unsigned char m_ucProductId;
    QString m_qsProductName;    //new added manu
    unsigned char m_ucProductLine;    //new added manu
    unsigned char m_ucProductType;    //new added manu
    QString productImagePath;
    unsigned char m_ucNumberOfPorts;
    unsigned char m_ucNumberOfFiberPorts;
    QRect m_oQRectPortGeometry[MAX_NO_OF_PORTS];
    uint8_t m_canhandleJumbo;   //If one port of a device cannot handle Jumbo, the whole device should not be configurable Jumbo ON per GUI
}SProductData;




typedef struct
{
    const char *pucconfigParameter; // string configuration parameter name from file
    uint8_t ucAllowedProductLine; // set bit 0: SL, set bit 1: PL, set bit 2: POE, Set all three bits for ALL
    uint8_t  ucAllowedProductType; // set bit 0: FE, set bit 1: GE, Set all two bits for ALL
    uint8_t  ucDependsOnProductId; // the no. of indexes depends on no. of ports

    /*minIndex & maxIndex specify range of indexes possible for this parameter for non-port based configuration parameter */
    uint8_t  ucMinIndex;
    uint8_t  ucMaxIndex;
    uint8_t flags; // a set of flags which are defined below
    #define FILE_VALID_FLAG_IS_STRING 1
    #define FILE_VALID_FLAG_DO_NOT_STORE 2
    #define FILE_VALID_FLAG_SPECIAL_QOS_PORT    0x10


    /*minIndex & maxIndex specify range of values possible for this parameter*/
    uint8_t  ucMinValue;

    uint32_t  ucMaxValue;/*unsigned char  ucMaxValue;   manu*/

    uint32_t  ucOffsetOfParaInConfigStruct;
    uint8_t  ucMakeIndexMinus1;
} gstconfigFileValidStruct;


const gstconfigFileValidStruct validateConfigDB[] = {
    //1 Name  //2 ProductLine   //3 ProductType   //4 Product ID
    //5 MinIndex  //6 MaxIndex  //7 Is string Value
    //8 MIn   //9 Max   //10 pffset    //
    {"file.creation-date",              7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"file.version",                    7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"alarm.psu",                       6, 3, 0, 1, 2, 0, 0, 1, offsetof(configData,aucalarmPsu),1},
    {"switch.aging-time",               7, 3, 0, 0, 0, 0, 0, 1048575, offsetof(configData,aucalarmPsu),0},
    {"qos.trust-mode",                  7, 3, 0, 0, 0, 0, 0, 2, offsetof(configData,globalTrustMode),0},
    {"traffic-class.priority-scheme",   7, 3, 0, 0, 3, 0, 0, 0, offsetof(configData,aucpriority),0},
    {"dot1p.traffic-class",             7, 3, 0, 0, 7, 0, 0, 3, offsetof(configData,aucdotp1PcpToTc),0},
    {"dscp.traffic-class",              7, 3, 0, 0, 63, 0, 0, 3, offsetof(configData,aucdscpD1D2),0},
    {"port.flow-control",               7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucflowControlStatus),1},
    {"port.admin-state",                7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucadminState),1},
    {"port.jumbo",                      7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucjumboFrameStatus),1},
    {"port.bc-storm.protection",        7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucbcStormStatus),1},
    {"port.bc-storm.threshold",         7, 3, 1, 1, 0, 0, 0, 100, offsetof(configData,aucbcStormThresold),1},
    {"port.mc-storm.protection",        7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucmcStormStatus),1},
    {"port.mc-storm.threshold",         7, 3, 1, 1, 0, 0, 0, 100, offsetof(configData,aucmcStormThresold),1},
    {"port.qos.trust-mode",             7, 3, 1, 1, 0, FILE_VALID_FLAG_SPECIAL_QOS_PORT, 0, 2, offsetof(configData,aucTrustMode),1},   /* to be compatible with the old format */
    {"port.alarm.link",                 6, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,auclinkAlarmStatus),1},
    {"port.autoneg",                    7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucautonegStatus),1},
    {"port.speed",                      7, 3, 1, 1, 0, 0, 1, 2, offsetof(configData,aucspeed),1},
    {"port.duplex",                     7, 3, 1, 1, 0, 0, 1, 2, offsetof(configData,aucduplexMode),1},
    {"port.auto-crossing",              7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucautoCrossingstatus),1},
    {"port.mdi",                        7, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucMdistatus),1},
    {"port.eee",                        7, 2, 1, 1, 0, 0, 0, 1, offsetof(configData,aucEEEStatus),1},
    {"port.poe.admin-state",            4, 3, 1, 1, 0, 0, 0, 1, offsetof(configData,aucpoeStatus),1},
    {"port.poe.priority",               4, 3, 1, 1, 0, 0, 1, 3, offsetof(configData,aucpoePriority),1},
    {"port.poe.allowed-classes",        4, 3, 1, 1, 0, FILE_VALID_FLAG_IS_STRING, 0, 4, offsetof(configData,aucpoeAllowedClasses),1},
    {"port.poe.override",				4, 3, 1, 1, 0, 0, 0, 13, offsetof(configData,aucpoeAllowedConsumptionOverride),1},
    {"port.vlan.id",                    7, 3, 1, 1, 0, 0, 1, 4096, offsetof(configData,aucportVLANID),1},
    {"port.qos.port-based",             7, 3, 1, 1, 0, 0, 0, 7, offsetof(configData,aucportBasedQoS),1},	/*qos change request*/
    {"file.end",                        7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"file.configID",                   7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"file.contactname",                7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"file.location",                   7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0},
    {"file.command",                    7, 3, 0, 0, 0, FILE_VALID_FLAG_IS_STRING|FILE_VALID_FLAG_DO_NOT_STORE, 0, 0, 0,0}

};

#define MAX_ENTRIES_VALIDATE_CONFIG (sizeof(validateConfigDB)/sizeof(validateConfigDB[0]))



#define     DEFAULT_RELEASEFILE     0
#define     DEFAULT_AUCALARMPSU1    1
#define     DEFAULT_AUCALARMPSU2    1
#define     DEFAULT_AGEINGTIME      300
#define     DEFAULT_DOTP0           1
#define     DEFAULT_DOTP1           0
#define     DEFAULT_DOTP2           0
#define     DEFAULT_DOTP3           1
#define     DEFAULT_DOTP4           2
#define     DEFAULT_DOTP5           2
#define     DEFAULT_DOTP6           3
#define     DEFAULT_DOTP7           3
#define     DEFAULT_DSCP0           1
#define     DEFAULT_DSCP1           1
#define     DEFAULT_DSCP2           1
#define     DEFAULT_DSCP3           1
#define     DEFAULT_DSCP4           1
#define     DEFAULT_DSCP5           1
#define     DEFAULT_DSCP6           1
#define     DEFAULT_DSCP7           1
#define     DEFAULT_DSCP8           0
#define     DEFAULT_DSCP9           0
#define     DEFAULT_DSCP10           0
#define     DEFAULT_DSCP11           0
#define     DEFAULT_DSCP12           0
#define     DEFAULT_DSCP13           0
#define     DEFAULT_DSCP14           0
#define     DEFAULT_DSCP15           0
#define     DEFAULT_DSCP16           0
#define     DEFAULT_DSCP17           0
#define     DEFAULT_DSCP18           0
#define     DEFAULT_DSCP19           0
#define     DEFAULT_DSCP20           0
#define     DEFAULT_DSCP21           0
#define     DEFAULT_DSCP22           0
#define     DEFAULT_DSCP23           0
#define     DEFAULT_DSCP24           1
#define     DEFAULT_DSCP25           1
#define     DEFAULT_DSCP26           1
#define     DEFAULT_DSCP27           1
#define     DEFAULT_DSCP28           1
#define     DEFAULT_DSCP29           1
#define     DEFAULT_DSCP30           1
#define     DEFAULT_DSCP31           1
#define     DEFAULT_DSCP32           2
#define     DEFAULT_DSCP33           2
#define     DEFAULT_DSCP34           2
#define     DEFAULT_DSCP35           2
#define     DEFAULT_DSCP36           2
#define     DEFAULT_DSCP37           2
#define     DEFAULT_DSCP38           2
#define     DEFAULT_DSCP39           2
#define     DEFAULT_DSCP40           2
#define     DEFAULT_DSCP41           2
#define     DEFAULT_DSCP42           2
#define     DEFAULT_DSCP43           2
#define     DEFAULT_DSCP44           2
#define     DEFAULT_DSCP45           2
#define     DEFAULT_DSCP46           2
#define     DEFAULT_DSCP47           2
#define     DEFAULT_DSCP48           3
#define     DEFAULT_DSCP49           3
#define     DEFAULT_DSCP50           3
#define     DEFAULT_DSCP51           3
#define     DEFAULT_DSCP52           3
#define     DEFAULT_DSCP53           3
#define     DEFAULT_DSCP54           3
#define     DEFAULT_DSCP55           3
#define     DEFAULT_DSCP56           3
#define     DEFAULT_DSCP57           3
#define     DEFAULT_DSCP58           3
#define     DEFAULT_DSCP59           3
#define     DEFAULT_DSCP60           3
#define     DEFAULT_DSCP61           3
#define     DEFAULT_DSCP62           3
#define     DEFAULT_DSCP63           3

#define     DEFAULT_FLOWCONTROL      0
#define     DEFAULT_ADMINSTATE       1
#define     DEFAULT_BCSTORMSTATUS    0
#define     DEFAULT_BCSTORMTH        100
#define     DEFAULT_MCSTORMSTATUS    0
#define     DEFAULT_MCSTORMTH        100

#define     DEFAULT_TRUSTMODE       1
#define     DEFAULT_PORTPRIORITY    0
#define     DEFAULT_LINKALARM       0
#define     DEFAULT_AUTONEG         1
#define     DEFAULT_SPEED           2  //2
#define     DEFAULT_DUPLEX          2
#define     DEFAULT_JUMBOFRAME      0

#define     DEFAULT_AUTOCROSS       1
#define     DEFAULT_MDISTATUS       0   //1 earlier
#define     DEFAULT_EEE             0
#define     DEFAULT_POESTATUS       1
#define     DEFAULT_POEPRIORITY     1
#define     DEFAULT_POEALLOWEDCLASS0     0
#define     DEFAULT_POEALLOWEDCLASS1     1
#define     DEFAULT_POEALLOWEDCLASS2     2
#define     DEFAULT_POEALLOWEDCLASS3     3
#define     DEFAULT_POEALLOWEDCLASS4     4
#define     DEFAULT_POEALLOWEDCLASS5     255
#define     DEFAULT_POEALLOWEDCLASS6     255
#define     DEFAULT_POEALLOWEDCLASS7     255
#define     DEFAULT_POEOVERRIDE         0
#define     DEFAULT_VLANID              1


#define     TT_PRODUCTSELECTION     "Select product"
#define     TT_COMPONENTID          "Maximum 9 character alpha-numeric"
#define     TT_SERIALFIX            "Fixed serial number"
#define     TT_SERIALNUMBER         "9 digit numeric"
#define     TT_FILERELEASE          "Numeric and special character (.). Format xx.x.xx"
#define     TT_CONTACTNAME          "Upper and lower case english alphabets and special character (space only)"
#define     TT_LOCATION             "Upper and lower case english alphabets, numeric and special characters (space - / ( ) )"
#define     TT_PSUALARM1            ""
#define     TT_PSUALARM2            ""
#define     TT_AGEINGTIME           "Only numerical value with maximum value 1048575"
#define     TT_QOSMAPPING           ""
#define     TT_QOSDSCPMAPPING       ""
#define     TT_ADMINSTATE           ""
#define     TT_ADMINLINK            ""
#define     TT_SPEED                ""
#define     TT_AUTONEG              ""
#define     TT_AUTOCROSSING         ""
#define     TT_DUPLEXMODE           ""
#define     TT_FLOWCONTROL          ""
#define     TT_BCPROTECTION         ""
#define     TT_BCTHRESHOLD          "% value"
#define     TT_MCPROTECTION         ""
#define     TT_MCTHRESHOLD          "% value"
#define     TT_JUMBOFRAME           ""
#define     TT_QOSTRUST             ""
#define     TT_PORTPRIORITY         ""
#define     TT_EEE                  ""
#define     TT_POEADMINSTATE        ""
#define     TT_POEPRIORITY          ""
#define     TT_ALLOWEDPOE           "Numeric(0 to 4) and special character (,)"
#define     TT_OVERRIDEPOE          "Numeric(0 to 13, 0 will be displayed as '-')"
#define     TT_SELECTALL            "Select only TP Port"
#define     TT_DESELECTALL          ""

#define     STYLESHEET_GROUPBOX     "QGroupBox{padding: 5px;border: 1px solid white;border-radius: 2px;margin-top: 10px;} QGroupBox::title {top: -10px;left: 10px;}" //QGroupBox { font-size: 13px;font-weight: normal;}
#define     STYLESHEET_PRODUCTIMAGE "QGroupBox{padding: 5px;border: 2px solid white;border-radius: 2px;margin-bottom:6px;margin-top:6px;} QGroupBox::title {top: -10px;left: 10px;}"
#define     STYLESHEET_RADIOBUTTON  "border: transparent;"
#define     STYLESHEET_TRASPARENT   "background-color : transparent; border: transparent;font-size: 12px;"
#define     STYLESHEET_PORTDEFAULT  "background-color : transparent;border: 1px solid black"
#define     STYLESHEET_PORTSELECT   "background-color : transparent;border: 2px solid red"

#endif // GLOBALDATA_H

