/***************************** FILE HEADER *********************************/
/*!
*  \file      mainwindow.h
*
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include "globaldata.h"

#include <QDesktopWidget>
#include <QDesktopServices>
#include <QWidget>
#include <QLabel>
#include <QFrame>
#include <QSpinBox>
#include <QComboBox>
#include <QLineEdit>
#include <QGridLayout>
#include <QPushButton>
#include <QTextCursor>
#include <QPainter>
#include <QTextDocument>
#include <QTextTable>
#include <QActionGroup>
#include <QSettings>
#include <QSignalMapper>
#include <QStandardItemModel>

#include "clickQlabel.h"
#include "comboboxdelegate.h"
#include "spinboxdelegate.h"
#include "lineeditdelegate.h"
#include "dialog8021p.h"
#include "dialogdscp.h"
#include "aboutdialog.h"
#include "dialogerrorlog.h"
#include "cpdfreport.h"
#include "dialogconfigid.h"

namespace Ui {
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    ComboBoxDelegate *ComboBoxDelegateComboBox;
    SpinBoxDelegate *SpinBoxDelegateSpinBox;
    LineEditDelegate *LineEditDelegateLineEdit;

    clickQlabel *clickQlabelQLabelPort[MAX_NO_OF_PORTS];

    bool boolErrorLog;

private:
    Ui::MainWindow *ui;

    Dialog8021p *ptrDialog8021p;
    DialogDSCP *ptrDialogdscp;
    DialogErrorLog *ptrDialogErrorLog;
    DialogConfigID *ptrDialogConfigID;
    aboutDialog *ptrAbout;

    SELECTED_PORT_TYPE eSelectedPortType;
    bool boolCtrlFlag;
    QString QStringFileNamesLoad;


    QMenu *QMenuFileMenu;
    QMenu *QMenuDocumentationMenu;
    QMenu *QMenuOptionsMenu;
    QMenu *QMenuSettingsMenu;
    QMenu *QMenuHelpMenu;
    QMenu *QMenuLanguageMenu;
    QActionGroup *QActionGroupAlignmentGroup;

    QAction *QActionNewAct;
    QAction *QActionLoadAct;
    QAction *QActionSaveAct;
    QAction *QActionSaveAsAct;
    QAction *QActionSaveToUsbAct;
    QAction *QActionExitAct;

    QAction *QActionExportAct;

    QAction *QActionEngLanAct;
    QAction *QActionGerLanAct;

    QAction *QActionOnlineHelpAct;
    QAction *QActionWebSiteAct;
    QAction *QActionAboutAct;

    QSettings settings;
    QString m_sSettingsFile;

    int siLanguageSelection;
    int siUpdatePara;
    QString siOpenParticularHelp = "SwitchProgrammingTool.html";

    QStandardItemModel *QStandardItemModelModels;

    void MainWindowSettings();
    void validatorSettingForUI();

    void CreateActions();
    void CreateMenus();
    void CenterOfScreen();

    int readModelno(void);
    void readLogo();
    void processLineFromCSV(QString QStringLine);
    void readCSVFile(QString QStringFilename);

    void displayProductImage(int siIndex);
    void saveCSVFile(QString QStringFileName);

    void setupGreyedOutParameters(SELECTED_PORT_TYPE);

    void populateSinglePort(int siIndex);

    void configureDefaultData();

    void clearPortBorder();
    void createNewTable(int siNoOfPorts);

    void updateBufferfromDefault();
    void updteUserInterface();
    void updateGlobalParaUserInterface();
    void updatePortTableUserInterface();
    bool NoSaveWhnPrtDisabld();
    void onOpencsvfileCsvpopup(unsigned char configId);


    SELECTED_PORT_TYPE checkTypeofPort(int siLabel_number);

    void displayErrorLog();

    void toolTips();
    void radioSelectAll(bool boolStatus);
    void radioDeselectAll(bool boolStatus);

    void portUpdate(int siLabel_number);

public slots:
    void modelselection(int siIndex);
    void label_singleclick(int siLabel_number);
    void label_controlclick(int siLabel_number);

private slots:
    void setActive();

    void on_pushButton_qosDscpMapping_clicked();
    void on_pushButton_qosPMapping_clicked();

    void on_toolButton_allowedPoEOverride_info_clicked();

    void newFile();
    void open();
    void save();
    void saveAs();
    void saveToUsb();
    void exit();

    void exportReport();

    void engLan();
    void gerLan();

    void onlineHelp();
    void webSite();
    void about();

    void on_comboBox_adminState_currentIndexChanged(int siIndex);
    void on_comboBox_alarmLink_currentIndexChanged(int siIndex);
    void on_comboBox_speed_currentIndexChanged(int siIndex);
    void on_comboBox_autoNeg_currentIndexChanged(int siIndex);
    void on_comboBox_autoCrossing_currentIndexChanged(int siIndex);
    void on_comboBox_duplexMode_currentIndexChanged(int siIndex);
    void on_comboBox_mdiState_currentIndexChanged(int siIndex);
    void on_comboBox_flowControl_currentIndexChanged(int siIndex);
    void on_comboBox_broadcastStormProtection_currentIndexChanged(int siIndex);
    void on_spinBox_broadcastStormThreshold_valueChanged(int siArg1);
    void on_comboBox_multicastStormProtection_currentIndexChanged(int siIndex);
    void on_spinBox_multicastStormThreshold_valueChanged(int siArg1);
    void on_comboBox_jumboFrames_currentIndexChanged(int siIndex);
    void on_comboBox_qosTrustMode_currentIndexChanged(int siIndex);
    void on_comboBox_eee_currentIndexChanged(int siIndex);
    void on_comboBox_poeAdminState_currentIndexChanged(int siIndex);
    void on_comboBox_poePriority_currentIndexChanged(int siIndex);

    void currentIndexChangedfromTable(QString QStringCurrentValue);
    void on_radioButton_selectAll_clicked(bool boolChecked);
    void on_tableView_portSettings_clicked(const QModelIndex &QModelIndexIndex);
    void on_radioButton_deselectAll_clicked(bool boolChecked);

    void currentCellSelected(QModelIndex QModelIndexIndex);

    void on_lineEdit_fileRelease_textEdited(const QString &QStringarg1);
    void on_comboBox_psuAlarm1_currentIndexChanged(int siIndex);
    void on_comboBox_psuAlarm2_currentIndexChanged(int siIndex);
    void on_lineEdit_agingTime_textChanged(const QString &QStringArg1);
    void on_lineEdit_allowedPoEClasses_textChanged(const QString &QStringArg1);
    void on_spinBox_allowedPoEOverride_valueChanged(int siArg1);
    void on_lineEdit_contactName_textEdited(const QString &QStringArg1);
    void on_lineEdit_location_textEdited(const QString &QStringArg1);
    void on_lineEdit_componentId_textEdited(const QString &QStringArg1);

    void on_lineEdit_serialNumber_textEdited(const QString &QStringArg1);

    void on_comboBox_portpriority_currentIndexChanged(int siIndex);
};

#endif // MAINWINDOW_H
